\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{memoriaPFC}[2011/11/11 v0.4 Plantilla para hacer el PFC de la Facultad de Ingenieria de la Universidad de Deusto.]
\DeclareOption{borrador}{\PassOptionsToPackage{draft}{graphicx}}

\ProcessOptions
\LoadClass[10pt,a4paper,twoside]{scrbook}
\RequirePackage[automark,markuppercase]{scrpage2}
\RequirePackage[spanish,activeacute]{babel}
\RequirePackage[indentfirst]{titlesec}
\RequirePackage{titletoc}
\RequirePackage{url}
\RequirePackage{fancybox}
\RequirePackage[pdftex]{graphicx}
\RequirePackage[absolute]{textpos}
\RequirePackage{ifthen}
\RequirePackage[pdftex]{color}
\RequirePackage{fancyvrb}
\RequirePackage{amssymb}
\RequirePackage{multibib}
\RequirePackage{listings}
\RequirePackage[unicode=true,%
                hypertexnames=false,%
                colorlinks=true,%
                linkcolor=black,%
                bookmarks=true]{hyperref}

% Definiendo colores para los listados de código fuente
\definecolor{violet}{rgb}{0.5,0,0.5}
\definecolor{navy}{rgb}{0,0,0.5}
\definecolor{deusto}{cmyk}{1,.57,0,.02}
\definecolor{hellgelb}{rgb}{1,1,0.8}
\definecolor{colKeys}{rgb}{0,0,1}
\definecolor{colIdentifier}{rgb}{0,0,0}
\definecolor{colComments}{rgb}{1,0,0}
\definecolor{colString}{rgb}{0,0.5,0}

\lstset{
        float=hbp,
        basicstyle=\ttfamily\small,
        identifierstyle=\color{colIdentifier},
        keywordstyle=\color{colKeys},
        stringstyle=\color{colString},
        commentstyle=\color{colComments},
        columns=flexible,
        tabsize=4,
        frame=single,
        extendedchars=true,
        showspaces=false,
        showstringspaces=false,
        numbers=left,
        numberstyle=\tiny,
        breaklines=true,
        backgroundcolor=\color{hellgelb},
        breakautoindent=true,
        captionpos=b
}

%%
%% INDICE y GLOSARIO
%%

%\makeglossary
%\makeindex

% http://theoval.sys.uea.ac.uk/~nlct/latex/thesis/node25.html
%\glossaryname (por defecto "Glosario")
%\glossary{name=set,description=a collection of objects}

%%
%% PORTADA
%%

% Datos de la portada
%\newcommand{\autores}[4]{\def\@autorUno{#1}\def\@autorDos{#3}\def\@DNIUno{#2}\def\@DNIDos{#4}}
\newcommand{\autores}[2]{\def\@autorUno{#1}\def\@autorDos{#2}}
\newcommand{\titulacion}[1]{\def\@titulacion{#1}}
\newcommand{\director}[1]{\def\@director{Director: #1}}
\newcommand{\directora}[1]{\def\@director{Directora: #1}}
\newcommand{\resumen}[1]{\def\@resumen{#1}}
\newcommand{\descriptores}[1]{\def\@descriptores{#1}}

\AtBeginDocument{%
  \ifthenelse{\equal{\@autorDos}{}}{\def\@autores{\@autorUno}}{\def\@autores{\@autorUno{} y \@autorDos}}
  \hypersetup{pdftitle={\@title},pdfauthor={\@autores}}
  \hypersetup{pdfsubject={Proyecto Fin de Carrera},pdfkeywords={\@descriptores}}
  \pagestyle{CabeceraPFC}
}
%\AtEndDocument{%
  % Aparecen todas las fuentes, no solo las que citemos explicitamente en el texto
 %  \nocite{*}
%  \nociteotras{*}
%}

% Para dibujar una box de un ancho y alto especifico
\newcommand\xyparbox[4][c]{\mbox{%
  \dimen0=2\fboxrule\advance\dimen0 2\fboxsep
  \dimen1=#2\advance\dimen1 -\dimen0
  \dimen2=#3\advance\dimen2 -\dimen0
  \parbox[#1][\dimen2][c]{\dimen1}{#4}}}

% Comando que dibuja la portada
\newcommand{\hacerportada}{%
\begin{titlepage}%
% Logotipo de la Titulacion
%\begin{textblock*}{block_width}(x_loc_of_top_left, y_loc_of_top_left)
\begin{textblock*}{13cm}(1cm,2cm)%
   \includegraphics[width=7cm]{imgs/logo.png}%
\end{textblock*}%


\ifthenelse{\equal{\@titulacion}{ii}}{
  \begin{textblock*}{15cm}(2.7cm,9cm)%
    {\noindent\Huge\bf\color{deusto}{\sffamily Ingeniero en Inform\'atica}}\\%
    \\\vspace*{2ex}%
    {\noindent\Huge\bf\color{deusto}{\sffamily Informatikako Ingeniaria}}%
    \vspace{1.5cm}%
  \end{textblock*}%
}{}
\ifthenelse{\equal{\@titulacion}{ioi}}{
  \begin{textblock*}{15cm}(2.7cm,9cm)%
    {\noindent\Huge\bf\color{deusto}{\sffamily Ingeniero en Organizaci\'on Industrial}}\\%
    \\\vspace*{2ex}%
    {\noindent\Huge\bf\color{deusto}{\sffamily Industri Antolaketako Ingeniaria}}%
    \vspace{1.5cm}%
  \end{textblock*}%
}{}
\ifthenelse{\equal{\@titulacion}{iaei}}{
  \begin{textblock*}{15cm}(2.7cm,7cm)%
    {\noindent\Huge\bf\color{deusto}{\sffamily Ingeniero en Autom\'atica}}\\%
    {\noindent\Huge\bf\color{deusto}{\sffamily y Electr\'onica Industrial}}\\%
    \\\vspace*{2ex}%
    {\noindent\Huge\bf\color{deusto}{\sffamily Industri Automatika}}\\%
    {\noindent\Huge\bf\color{deusto}{\sffamily eta Elektronikako Ingeniaria}}%
    \vspace{1.5cm}%
  \end{textblock*}%
}{}
\ifthenelse{\equal{\@titulacion}{iiioi}}{
  \begin{textblock*}{15cm}(2.7cm,7cm)%
    {\noindent\Huge\bf\color{deusto}{\sffamily Ingeniero en Inform\'atica}}\\%
    {\noindent\Huge\bf\color{deusto}{\sffamily Ingeniero en Organizaci\'on Industrial}}\\%
    \\\vspace*{2ex}%
    {\noindent\Huge\bf\color{deusto}{\sffamily Informatikako Ingeniaria}}\\%
    {\noindent\Huge\bf\color{deusto}{\sffamily Industri Antolaketako Ingeniaria}}%
    \vspace{1.5cm}%
  \end{textblock*}%
}{}
\ifthenelse{\equal{\@titulacion}{it}}{
  \begin{textblock*}{15cm}(2.7cm,9cm)%
    {\noindent\Huge\bf\color{deusto}{\sffamily Ingeniero de Telecomunicaci\'on}}\\%
    \\\vspace*{2ex}%
    {\noindent\Huge\bf\color{deusto}{\sffamily Telekomunikazioko Ingeniaria}}%
    \vspace{1.5cm}%
  \end{textblock*}%
}{}


% Titulo (Pfc) y subtitulo (título del proyecto)
\begin{textblock*}{16cm}(2.7cm,12.3cm)%
    {\noindent\Huge\bf\sffamily Proyecto fin de carrera}\\%
    \\\vspace*{2ex}%
    {\noindent\Huge\bf\sffamily Karrera amaierako proiektua}
    \vspace{.5cm}\\%
    {\huge\sffamily\@title{}}%
\end{textblock*}%

% Autores
\begin{textblock*}{16cm}(2.7cm,21.5cm)%
    {\noindent\Large\sffamily\@autorUno{}}\\%
    \ifthenelse{\equal{\@autorDos}{}}{}{\Large\sffamily\@autorDos{}\\}%
\end{textblock*}%

% Director y fecha
\begin{textblock*}{16cm}(2.7cm,25.1cm)%
  {\noindent\Large\sffamily \@director{}}\\%
  \vspace*{2ex}\\%
  {\Large\sffamily Bilbao, \@date{}}%
\end{textblock*}%
\end{titlepage}%
\mbox{}
\vfill
\cleardoublepage\pagebreak%
\rmfamily
}


%%
%% RESUMEN
%%

% Comando que crea la página resumen
\newcommand{\hacerresumen}{%
  \cleardoublepage\pagebreak
  \subsection*{Resumen}
  \@resumen
  \subsection*{Descriptores}
  \@descriptores
  \thispagestyle{plain}
}



%%
%% FORMATO DE LA PAGINA
%%
% Necesitas que:
% - en la parte superior se deje (hasta el cuerpo) 3cm
% - la cabecera esté a 2cm de la parte superior [del cuerpo]
% Por tanto:
%
% 3cm = 1 in + \voffset + \topmargin + \headheight + \headsep
% 2cm = \headsep
%
% Traducimos en órdenes LaTeX.
% Respetamos los valores por defecto de \voffset y \headheight.
% Pon los valores adecuados si quieres cambiarlos:
% \setlength{\voffset}{XXX}
% \setlength{\headheight}{XXX}
% Asignamos valor a \headsep y deducimos el de \topmargin:
\setlength{\headsep}{2cm}
\setlength{\topmargin}{3cm}
\addtolength{\topmargin}{-1in}
\addtolength{\topmargin}{-\voffset}
\addtolength{\topmargin}{-\headheight}
\addtolength{\topmargin}{-\headsep}

% Necesitas que:
% - en la parte inferior se deje (desde el cuerpo) 3cm
% - el pie esté a 1cm de la parte inferior
% Por tanto, teniendo en cuenta el espacio dedicado a la cabecera y
% margen superior:
%
% \paperheight = 3 cm + \textheight + 3cm
% 2 cm = \footskip
%
% El valor de \paperheight se asigna mediante la opción a4paper de
% \documentclass o \LoadClass. Falta lo siguiente:
\setlength{\footskip}{2cm}
\setlength{\textheight}{\paperheight}
\addtolength{\textheight}{-6cm}

% Necesitas que:
% - en la parte izquierda del documento se deje 3.5cm
% - en la parte derecha del documento se deje 2.5cm
% Dado que es un documento a dos caras, se tiene:
% 3.5 cm = 1 in + \hoffset + \oddsidemargin
% 2.5 cm = 1 in + \hoffset + \evensidemargin
% \paperwith = 3.5 cm + \textwidth + 2.5 cm
%
% Mantenemos el valor de \hoffset. Modifica la orden siguiente
% si quieres cambiarlo:
%\setlength{\hoffset}{XXX}
\setlength{\oddsidemargin}{3.5 cm}
\addtolength{\oddsidemargin}{-1in}
\addtolength{\oddsidemargin}{-\hoffset}
\setlength{\evensidemargin}{2.5 cm}
\addtolength{\evensidemargin}{-1in}
\addtolength{\evensidemargin}{-\hoffset}
\setlength{\textwidth}{\paperwidth}
\addtolength{\textwidth}{-6cm}

% Para compilar con pdfLaTeX:
\setlength{\pdfpagewidth}{\paperwidth}
\setlength{\pdfpageheight}{\paperheight}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Esta es la tabla que aparece en la cabecera
\newcommand{\cabeceraimpar}{\textit{\headmark}}
\newcommand{\cabecerapar}{\textit{PROYECTO FIN DE CARRERA}}

% Creamos un estilo de página corporativo - UD
\newpagestyle{CabeceraPFC}
% Definicion de la cabecera:
{(0pt,0pt){\cabeceraimpar\hfill}{\hfill\cabecerapar}{\hfill\headmark\hfill}(0pt,0pt)}%
% Definición del pie de pagina:
{(0pt,0pt){\pagemark\hfill}{\hfill\pagemark}{\hfill\headmark\hfill}(0pt,0pt)}

% Sólo muestra secciones en el encabezado
%\automark[section]{section}
% Sólo muestra capítulos en el encabezado
%\automark[chapter]{section}
\automark[section]{chapter}

% Redefinimos el estilo de página "plain", que es el que aparece
% en las 'primeras páginas' de capitulos, etc. En principio, es
% exactamente igual que la anterior.
\renewpagestyle{plain}%
% Definicion de la cabecera:
{(0pt,0pt){\cabeceraimpar\hfill}{\hfill\cabecerapar}{\hfill\headmark\hfill}(0pt,0pt)}%
% Definición del pie de pagina:
{(0pt,0pt){\pagemark\hfill}{\hfill\pagemark}{\hfill\headmark\hfill}(0pt,0pt)}

% Por defecto, estilo de página corporativo
\pagestyle{CabeceraPFC}

% Esto es para que no aparezca el numero de página en las páginas en blanco.
\makeatletter
\def\cleardoublepage{\clearpage\if@twoside \ifodd\c@page\else
  \hbox{}
  \vspace*{\fill}
  \vspace{\fill}
  \thispagestyle{empty}
  \newpage
  \if@twocolumn\hbox{}\newpage\fi\fi\fi}
\makeatother



%%
%% ENCABEZADOS DE SECCIONES
%%

\renewcommand{\frontmatter}{%
  % Eliminamos cabeceras
  \pagestyle{plain}%
  \renewcommand{\cabecerapar}{}%
  \renewcommand{\cabeceraimpar}{}%
  \pagenumbering{roman}%
}

\renewcommand{\mainmatter}{%
\cleardoublepage
\pagestyle{CabeceraPFC}
\renewcommand{\cabeceraimpar}{\textit{\headmark}}
\renewcommand{\cabecerapar}{\textit{PROYECTO FIN DE CARRERA}}
\pagenumbering{arabic}

%\contentsmargin{2.55em}
% Redefinimos el formato de \chapter
\titleformat{\chapter}[block]{\sffamily\huge}{\bfseries\thechapter.}{.5em}{\filleft\bfseries\MakeUppercase}[\titlerule\vspace{2ex}]
\titlecontents{chapter}[0em]{\smallskip\bfseries\sffamily}{\contentslabel{1em}}{\hspace*{0em}}{}
\titlespacing*{\chapter}{0pt}{*4}{*1}

% Redefinimos el formato de \section
\titleformat{\section}[block]{\sffamily\Large}{\bfseries\thesection}{.5em}{\bfseries\MakeUppercase}
\titlecontents{section}[2em]{\sffamily}{\contentslabel{2em}}{\hspace*{0em}}{\titlerule*[.7pc]{.}\contentspage}
\titlespacing*{\section}{0pt}{*4}{*1}

% Redefinimos el formato de \subsection
\titleformat{\subsection}[block]{\sffamily\large}{\bfseries\thesubsection}{.5em}{\bfseries}
\titlecontents{subsection}[5em]{\sffamily}{\contentslabel{3em}}{\hspace*{0em}}{\titlerule*[.7pc]{.}\contentspage}
\titlespacing*{\subsection}{0pt}{*4}{*1}

% Redefinimos el formato de \subsubsection
\titleformat{\subsubsection}[block]{\sffamily\normalsize}{}{0pt}{$\,\blacksquare\;\;\;$\bfseries}
\titlespacing*{\subsubsection}{0pt}{*4}{0.5ex}
}

\titlecontents{figure}[5em]{\sffamily}{\contentslabel{3em}}{\hspace*{0em}}{\titlerule*[.7pc]{.}\contentspage}
\titlecontents{table}[5em]{\sffamily}{\contentslabel{3em}}{\hspace*{0em}}{\titlerule*[.7pc]{.}\contentspage}
\makeatletter
\renewcommand*{\l@lstlisting}[2]{\@dottedtocline{1}{2em}{3em}{\sffamily#1}{\sffamily#2}}
\makeatother


%fin mainmatter

\renewcommand{\backmatter}{%
% Redefinimos el comando \chapter para los capitulos de la memoria
\titleformat{\chapter}[block]{\normalfont\sffamily\huge}{\bfseries\thechapter.}{.5em}{\filleft\bfseries\MakeUppercase}[\titlerule\vspace{2ex}]
\titlespacing*{\chapter}{0pt}{*4}{*1}
}

% Espaciado entre párrafos
\setlength{\parskip}{3ex plus 0.5ex minus 0.2ex}

%%
%% COMANDOS
%%

% Estas definiciones son para el comando \figura
% \newlength{\anchoFigura}
% \newlength{\anchoFloat}
% \addtolength{\fboxsep}{2\fboxsep}
% \renewcommand{\capfont}{\normalfont\normalcolor\sffamily\small}
% \renewcommand{\caplabelfont}{\normalfont\normalcolor\sffamily\bfseries\small}
%
% % El comando \figura nos permite insertar figuras comodamente, y utilizando
% % siempre el mismo formato. Los parametros son:
% % 1 -> Porcentaje del ancho de página que ocupará la figura (de 0 a 1)
% % 2 --> Fichero de la imagen
% % 3 --> Texto a pie de imagen
% % 4 --> Etiqueta (label) para referencias
% % 5 --> Opciones que queramos pasarle al \includegraphics
% \newcommand{\figura}[5]{%
%   \setlength{\anchoFloat}{#1\textwidth}%
%   \addtolength{\anchoFloat}{-4\fboxsep}%
%   \setlength{\anchoFigura}{\anchoFloat}%
%   \begin{figure}%
%     \begin{center}%
%       \Ovalbox{%
%         \begin{minipage}{\anchoFloat}%
%           \begin{center}%
%             \includegraphics[width=\anchoFigura,#5]{#2}%
%             \caption{#3}%
%             \label{#4}%
%           \end{center}%
%         \end{minipage}
%       }%
%     \end{center}%
%   \end{figure}%
% }
%
% % El comando \figuraSinMarco es igual que \figura, pero no pone marco a la figura.
% % Viene bien para diagramas grandes.
% \newcommand{\figuraSinMarco}[5]{%
%   \begin{figure}%
%     \begin{center}%
%     \includegraphics[width=#1\textwidth,#5]{#2}%
%     \caption{#3}%
%     \label{#4}%
%     \end{center}%
%   \end{figure}%
% }
%
% % Referencia a una figura
% \newcommand{\ver}[1]{(ver figura~\ref{#1})}
%
%
% % Para escribir extractos de codigo
% %
% % Las tabulaciones se substituyen por dos espacios
% \fvset{tabsize=2}
% % Creamos un nuevo environment de fancyvrb para los ejemplos enmarcados
% \DefineVerbatimEnvironment{VerbEj}{BVerbatim}{fontsize=\small,samepage=true,commandchars=\\\{\}}
% % Colo de fondo
% \definecolor{grisfondo}{gray}{0.9}
% % Environment para extractos de codigo
% \newenvironment{codigo}%
% {\VerbatimEnvironment\begin{Sbox}\begin{VerbEj}}%
% {\end{VerbEj}\end{Sbox}\setlength{\fboxsep}{8pt}\begin{center}\fcolorbox{black}{grisfondo}{\TheSbox}\end{center}}
%
% % Otro formato más bonito para código fuente
% \newcommand{\codigofuente}[3]{%
%   \lstinputlisting[language=#1,caption={#2}]{#3}%
% }
%
% % Para el preambulos de los capitulos
% \newenvironment{precapitulo}%
% {\begin{center}\begin{quote}\sffamily}%
% {\end{quote}\end{center}}


%%
%% Miscelanea
%%

% Esto es para que los primeros parrafos no esten indentados
%\makeatletter
%\let\@afterindenttrue\@afterindentfalse
%\@afterindentfalse
%\makeatother

% Definimos el nivel de detalle del índice: \section
% \setcounter{tocdepth}{1}

% Redefinimos el nombre de las tablas.
% En babel está traducido por 'Cuadro' :-?
%\addto\captionsspanish{\renewcommand{\tablename}{Tabla}}
%\addto\captionsspanish{\renewcommand{\listtablename}{\'Indice de tablas}}


%\newcites{otras}{Bibliograf\'ia (Otras fuentes)}

% Comandos para insertar comodamente las dos bibliografias de la memoria:
% la de libros y articulos, y la de 'otras fuentes'.
\newcommand{\bibliografia}[1]{%
  \cleardoublepage \addcontentsline{toc}{chapter}{Bibliograf\'ia}
  \renewcommand{\bibname}{BIBLIOGRAFÍA}
  %\renewcommand{\bibname}{Bibliografía (Libros y artículos)}
  %\renewcommand{\bibname}{BIBLIOGRAFÍA}
  %
  %\cleardoublepage \addcontentsline{toc}{chapter}{Bibliografía}
  %\renewcommand{\bibname}{Bibliografía}

  %\bibliographystyle{aalphaurl}
  \bibliographystyle{is-alpha-espanol}
  \bibliography{#1}
}

%\newcommand{\bibliografiaOtras}[1]{%
 % \cleardoublepage \addcontentsline{toc}{chapter}{Bibliograf\'ia (Otras fuentes)}
  %\renewcommand{\bibname}{Bibliografía (Otras fuentes documentales)}
  %\renewcommand{\bibname}{BIBLIOGRAF\'IA (OTRAS FUENTES)}
  %\bibliographystyleotras{is-alpha-espanol}
  %\bibliographyotras{#1}
%}


% Listados de código fuente
\renewcommand{\lstlistlistingname}{\'Indice de Seudoc\'odigos}
\renewcommand{\lstlistingname}{Seudoc\'odigo}
